pub struct Range {
pub drop: bool,
pub start: u64,
pub length: u64,
}Expand description
Range message. Type 8. Notifies Peer’s that the Sender has a range of contiguous blocks.
Fields
drop: boolIf true, notifies that data has been cleared from this range. If false, notifies existing data range.
start: u64Range starts at this index
length: u64Length of the range